@@ -30,8 +30,9 @@ class RecurrenceWidget(LinesWidget):
         portal = getToolByName(getSite(), 'portal_url').getPortalObject()
         ajax_url = portal.absolute_url() + '/@@json_recurrence'
         request = portal.REQUEST
+
         first_day = self.first_day
-        first_day = safe_callable(first_day) and first_day() or first_day
+        first_day = first_day() if safe_callable(first_day) else first_day
 
         params = dict(
             ajaxContentType='application/x-www-form-urlencoded; charset=UTF-8',
